@@ -13,6 +13,7 @@ Usage::
         DescribeCacheSubnetGroupsPaginator,
         DescribeEngineDefaultParametersPaginator,
         DescribeEventsPaginator,
+        DescribeGlobalReplicationGroupsPaginator,
         DescribeReplicationGroupsPaginator,
         DescribeReservedCacheNodesPaginator,
         DescribeReservedCacheNodesOfferingsPaginator,
@@ -31,6 +32,7 @@ Usage::
     describe_cache_subnet_groups_paginator: DescribeCacheSubnetGroupsPaginator = client.get_paginator("describe_cache_subnet_groups")
     describe_engine_default_parameters_paginator: DescribeEngineDefaultParametersPaginator = client.get_paginator("describe_engine_default_parameters")
     describe_events_paginator: DescribeEventsPaginator = client.get_paginator("describe_events")
+    describe_global_replication_groups_paginator: DescribeGlobalReplicationGroupsPaginator = client.get_paginator("describe_global_replication_groups")
     describe_replication_groups_paginator: DescribeReplicationGroupsPaginator = client.get_paginator("describe_replication_groups")
     describe_reserved_cache_nodes_paginator: DescribeReservedCacheNodesPaginator = client.get_paginator("describe_reserved_cache_nodes")
     describe_reserved_cache_nodes_offerings_paginator: DescribeReservedCacheNodesOfferingsPaginator = client.get_paginator("describe_reserved_cache_nodes_offerings")
@@ -51,6 +53,7 @@ from mypy_boto3_elasticache.type_defs import (
     CacheSecurityGroupMessageTypeDef,
     CacheSubnetGroupMessageTypeDef,
     DescribeEngineDefaultParametersResultTypeDef,
+    DescribeGlobalReplicationGroupsResultTypeDef,
     DescribeSnapshotsListMessageTypeDef,
     EventsMessageTypeDef,
     PaginatorConfigTypeDef,
@@ -77,6 +80,7 @@ __all__ = (
     "DescribeCacheSubnetGroupsPaginator",
     "DescribeEngineDefaultParametersPaginator",
     "DescribeEventsPaginator",
+    "DescribeGlobalReplicationGroupsPaginator",
     "DescribeReplicationGroupsPaginator",
     "DescribeReservedCacheNodesPaginator",
     "DescribeReservedCacheNodesOfferingsPaginator",
@@ -88,7 +92,7 @@ __all__ = (
 
 class DescribeCacheClustersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeCacheClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheClusters)
+    [Paginator.DescribeCacheClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheClusters)
     """
 
     def paginate(
@@ -99,13 +103,13 @@ class DescribeCacheClustersPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[CacheClusterMessageTypeDef]:
         """
-        [DescribeCacheClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheClusters.paginate)
+        [DescribeCacheClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheClusters.paginate)
         """
 
 
 class DescribeCacheEngineVersionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeCacheEngineVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheEngineVersions)
+    [Paginator.DescribeCacheEngineVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheEngineVersions)
     """
 
     def paginate(
@@ -117,26 +121,26 @@ class DescribeCacheEngineVersionsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[CacheEngineVersionMessageTypeDef]:
         """
-        [DescribeCacheEngineVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheEngineVersions.paginate)
+        [DescribeCacheEngineVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheEngineVersions.paginate)
         """
 
 
 class DescribeCacheParameterGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeCacheParameterGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameterGroups)
+    [Paginator.DescribeCacheParameterGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameterGroups)
     """
 
     def paginate(
         self, CacheParameterGroupName: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[CacheParameterGroupsMessageTypeDef]:
         """
-        [DescribeCacheParameterGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameterGroups.paginate)
+        [DescribeCacheParameterGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameterGroups.paginate)
         """
 
 
 class DescribeCacheParametersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeCacheParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameters)
+    [Paginator.DescribeCacheParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameters)
     """
 
     def paginate(
@@ -146,52 +150,52 @@ class DescribeCacheParametersPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[CacheParameterGroupDetailsTypeDef]:
         """
-        [DescribeCacheParameters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameters.paginate)
+        [DescribeCacheParameters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheParameters.paginate)
         """
 
 
 class DescribeCacheSecurityGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeCacheSecurityGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSecurityGroups)
+    [Paginator.DescribeCacheSecurityGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSecurityGroups)
     """
 
     def paginate(
         self, CacheSecurityGroupName: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[CacheSecurityGroupMessageTypeDef]:
         """
-        [DescribeCacheSecurityGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSecurityGroups.paginate)
+        [DescribeCacheSecurityGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSecurityGroups.paginate)
         """
 
 
 class DescribeCacheSubnetGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeCacheSubnetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSubnetGroups)
+    [Paginator.DescribeCacheSubnetGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSubnetGroups)
     """
 
     def paginate(
         self, CacheSubnetGroupName: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[CacheSubnetGroupMessageTypeDef]:
         """
-        [DescribeCacheSubnetGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSubnetGroups.paginate)
+        [DescribeCacheSubnetGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeCacheSubnetGroups.paginate)
         """
 
 
 class DescribeEngineDefaultParametersPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeEngineDefaultParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEngineDefaultParameters)
+    [Paginator.DescribeEngineDefaultParameters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEngineDefaultParameters)
     """
 
     def paginate(
         self, CacheParameterGroupFamily: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[DescribeEngineDefaultParametersResultTypeDef]:
         """
-        [DescribeEngineDefaultParameters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEngineDefaultParameters.paginate)
+        [DescribeEngineDefaultParameters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEngineDefaultParameters.paginate)
         """
 
 
 class DescribeEventsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEvents)
+    [Paginator.DescribeEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEvents)
     """
 
     def paginate(
@@ -210,26 +214,42 @@ class DescribeEventsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[EventsMessageTypeDef]:
         """
-        [DescribeEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEvents.paginate)
+        [DescribeEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeEvents.paginate)
+        """
+
+
+class DescribeGlobalReplicationGroupsPaginator(Boto3Paginator):
+    """
+    [Paginator.DescribeGlobalReplicationGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeGlobalReplicationGroups)
+    """
+
+    def paginate(
+        self,
+        GlobalReplicationGroupId: str = None,
+        ShowMemberInfo: bool = None,
+        PaginationConfig: PaginatorConfigTypeDef = None,
+    ) -> Iterator[DescribeGlobalReplicationGroupsResultTypeDef]:
+        """
+        [DescribeGlobalReplicationGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeGlobalReplicationGroups.paginate)
         """
 
 
 class DescribeReplicationGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeReplicationGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReplicationGroups)
+    [Paginator.DescribeReplicationGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReplicationGroups)
     """
 
     def paginate(
         self, ReplicationGroupId: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ReplicationGroupMessageTypeDef]:
         """
-        [DescribeReplicationGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReplicationGroups.paginate)
+        [DescribeReplicationGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReplicationGroups.paginate)
         """
 
 
 class DescribeReservedCacheNodesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeReservedCacheNodes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodes)
+    [Paginator.DescribeReservedCacheNodes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodes)
     """
 
     def paginate(
@@ -243,13 +263,13 @@ class DescribeReservedCacheNodesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ReservedCacheNodeMessageTypeDef]:
         """
-        [DescribeReservedCacheNodes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodes.paginate)
+        [DescribeReservedCacheNodes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodes.paginate)
         """
 
 
 class DescribeReservedCacheNodesOfferingsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeReservedCacheNodesOfferings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodesOfferings)
+    [Paginator.DescribeReservedCacheNodesOfferings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodesOfferings)
     """
 
     def paginate(
@@ -262,13 +282,13 @@ class DescribeReservedCacheNodesOfferingsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ReservedCacheNodesOfferingMessageTypeDef]:
         """
-        [DescribeReservedCacheNodesOfferings.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodesOfferings.paginate)
+        [DescribeReservedCacheNodesOfferings.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeReservedCacheNodesOfferings.paginate)
         """
 
 
 class DescribeServiceUpdatesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeServiceUpdates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeServiceUpdates)
+    [Paginator.DescribeServiceUpdates documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeServiceUpdates)
     """
 
     def paginate(
@@ -278,13 +298,13 @@ class DescribeServiceUpdatesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ServiceUpdatesMessageTypeDef]:
         """
-        [DescribeServiceUpdates.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeServiceUpdates.paginate)
+        [DescribeServiceUpdates.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeServiceUpdates.paginate)
         """
 
 
 class DescribeSnapshotsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeSnapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeSnapshots)
+    [Paginator.DescribeSnapshots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeSnapshots)
     """
 
     def paginate(
@@ -297,13 +317,13 @@ class DescribeSnapshotsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeSnapshotsListMessageTypeDef]:
         """
-        [DescribeSnapshots.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeSnapshots.paginate)
+        [DescribeSnapshots.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeSnapshots.paginate)
         """
 
 
 class DescribeUpdateActionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeUpdateActions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUpdateActions)
+    [Paginator.DescribeUpdateActions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUpdateActions)
     """
 
     def paginate(
@@ -323,5 +343,5 @@ class DescribeUpdateActionsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[UpdateActionsMessageTypeDef]:
         """
-        [DescribeUpdateActions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.19/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUpdateActions.paginate)
+        [DescribeUpdateActions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.30/reference/services/elasticache.html#ElastiCache.Paginator.DescribeUpdateActions.paginate)
         """
