@@ -49,6 +49,7 @@ __all__ = (
     "SubnetTypeDef",
     "CacheSubnetGroupTypeDef",
     "CacheSubnetGroupMessageTypeDef",
+    "GlobalReplicationGroupInfoTypeDef",
     "NodeGroupMemberTypeDef",
     "NodeGroupTypeDef",
     "SlotMigrationTypeDef",
@@ -65,21 +66,32 @@ __all__ = (
     "CreateCacheParameterGroupResultTypeDef",
     "CreateCacheSecurityGroupResultTypeDef",
     "CreateCacheSubnetGroupResultTypeDef",
+    "GlobalNodeGroupTypeDef",
+    "GlobalReplicationGroupMemberTypeDef",
+    "GlobalReplicationGroupTypeDef",
+    "CreateGlobalReplicationGroupResultTypeDef",
     "CreateReplicationGroupResultTypeDef",
     "CreateSnapshotResultTypeDef",
     "CustomerNodeEndpointTypeDef",
+    "DecreaseNodeGroupsInGlobalReplicationGroupResultTypeDef",
     "DecreaseReplicaCountResultTypeDef",
     "DeleteCacheClusterResultTypeDef",
+    "DeleteGlobalReplicationGroupResultTypeDef",
     "DeleteReplicationGroupResultTypeDef",
     "DeleteSnapshotResultTypeDef",
     "EngineDefaultsTypeDef",
     "DescribeEngineDefaultParametersResultTypeDef",
+    "DescribeGlobalReplicationGroupsResultTypeDef",
     "DescribeSnapshotsListMessageTypeDef",
+    "DisassociateGlobalReplicationGroupResultTypeDef",
     "EventTypeDef",
     "EventsMessageTypeDef",
+    "FailoverGlobalReplicationGroupResultTypeDef",
+    "IncreaseNodeGroupsInGlobalReplicationGroupResultTypeDef",
     "IncreaseReplicaCountResultTypeDef",
     "ModifyCacheClusterResultTypeDef",
     "ModifyCacheSubnetGroupResultTypeDef",
+    "ModifyGlobalReplicationGroupResultTypeDef",
     "ModifyReplicationGroupResultTypeDef",
     "ModifyReplicationGroupShardConfigurationResultTypeDef",
     "PaginatorConfigTypeDef",
@@ -87,12 +99,14 @@ __all__ = (
     "RecurringChargeTypeDef",
     "ReservedCacheNodeTypeDef",
     "PurchaseReservedCacheNodesOfferingResultTypeDef",
+    "RebalanceSlotsInGlobalReplicationGroupResultTypeDef",
     "RebootCacheClusterResultTypeDef",
+    "ReshardingConfigurationTypeDef",
+    "RegionalConfigurationTypeDef",
     "ReplicationGroupMessageTypeDef",
     "ReservedCacheNodeMessageTypeDef",
     "ReservedCacheNodesOfferingTypeDef",
     "ReservedCacheNodesOfferingMessageTypeDef",
-    "ReshardingConfigurationTypeDef",
     "RevokeCacheSecurityGroupIngressResultTypeDef",
     "ServiceUpdateTypeDef",
     "ServiceUpdatesMessageTypeDef",
@@ -302,7 +316,12 @@ CacheParameterGroupNameMessageTypeDef = TypedDict(
 
 CacheParameterGroupTypeDef = TypedDict(
     "CacheParameterGroupTypeDef",
-    {"CacheParameterGroupName": str, "CacheParameterGroupFamily": str, "Description": str},
+    {
+        "CacheParameterGroupName": str,
+        "CacheParameterGroupFamily": str,
+        "Description": str,
+        "IsGlobal": bool,
+    },
     total=False,
 )
 
@@ -343,6 +362,12 @@ CacheSubnetGroupMessageTypeDef = TypedDict(
     total=False,
 )
 
+GlobalReplicationGroupInfoTypeDef = TypedDict(
+    "GlobalReplicationGroupInfoTypeDef",
+    {"GlobalReplicationGroupId": str, "GlobalReplicationGroupMemberRole": str},
+    total=False,
+)
+
 NodeGroupMemberTypeDef = TypedDict(
     "NodeGroupMemberTypeDef",
     {
@@ -390,6 +415,7 @@ ReplicationGroupTypeDef = TypedDict(
     {
         "ReplicationGroupId": str,
         "Description": str,
+        "GlobalReplicationGroupInfo": GlobalReplicationGroupInfoTypeDef,
         "Status": str,
         "PendingModifiedValues": ReplicationGroupPendingModifiedValuesTypeDef,
         "MemberClusters": List[str],
@@ -510,6 +536,47 @@ CreateCacheSubnetGroupResultTypeDef = TypedDict(
     total=False,
 )
 
+GlobalNodeGroupTypeDef = TypedDict(
+    "GlobalNodeGroupTypeDef", {"GlobalNodeGroupId": str, "Slots": str}, total=False
+)
+
+GlobalReplicationGroupMemberTypeDef = TypedDict(
+    "GlobalReplicationGroupMemberTypeDef",
+    {
+        "ReplicationGroupId": str,
+        "ReplicationGroupRegion": str,
+        "Role": str,
+        "AutomaticFailover": Literal["enabled", "disabled", "enabling", "disabling"],
+        "Status": str,
+    },
+    total=False,
+)
+
+GlobalReplicationGroupTypeDef = TypedDict(
+    "GlobalReplicationGroupTypeDef",
+    {
+        "GlobalReplicationGroupId": str,
+        "GlobalReplicationGroupDescription": str,
+        "Status": str,
+        "CacheNodeType": str,
+        "Engine": str,
+        "EngineVersion": str,
+        "Members": List[GlobalReplicationGroupMemberTypeDef],
+        "ClusterEnabled": bool,
+        "GlobalNodeGroups": List[GlobalNodeGroupTypeDef],
+        "AuthTokenEnabled": bool,
+        "TransitEncryptionEnabled": bool,
+        "AtRestEncryptionEnabled": bool,
+    },
+    total=False,
+)
+
+CreateGlobalReplicationGroupResultTypeDef = TypedDict(
+    "CreateGlobalReplicationGroupResultTypeDef",
+    {"GlobalReplicationGroup": GlobalReplicationGroupTypeDef},
+    total=False,
+)
+
 CreateReplicationGroupResultTypeDef = TypedDict(
     "CreateReplicationGroupResultTypeDef",
     {"ReplicationGroup": ReplicationGroupTypeDef},
@@ -524,6 +591,12 @@ CustomerNodeEndpointTypeDef = TypedDict(
     "CustomerNodeEndpointTypeDef", {"Address": str, "Port": int}, total=False
 )
 
+DecreaseNodeGroupsInGlobalReplicationGroupResultTypeDef = TypedDict(
+    "DecreaseNodeGroupsInGlobalReplicationGroupResultTypeDef",
+    {"GlobalReplicationGroup": GlobalReplicationGroupTypeDef},
+    total=False,
+)
+
 DecreaseReplicaCountResultTypeDef = TypedDict(
     "DecreaseReplicaCountResultTypeDef", {"ReplicationGroup": ReplicationGroupTypeDef}, total=False
 )
@@ -532,6 +605,12 @@ DeleteCacheClusterResultTypeDef = TypedDict(
     "DeleteCacheClusterResultTypeDef", {"CacheCluster": CacheClusterTypeDef}, total=False
 )
 
+DeleteGlobalReplicationGroupResultTypeDef = TypedDict(
+    "DeleteGlobalReplicationGroupResultTypeDef",
+    {"GlobalReplicationGroup": GlobalReplicationGroupTypeDef},
+    total=False,
+)
+
 DeleteReplicationGroupResultTypeDef = TypedDict(
     "DeleteReplicationGroupResultTypeDef",
     {"ReplicationGroup": ReplicationGroupTypeDef},
@@ -559,12 +638,24 @@ DescribeEngineDefaultParametersResultTypeDef = TypedDict(
     total=False,
 )
 
+DescribeGlobalReplicationGroupsResultTypeDef = TypedDict(
+    "DescribeGlobalReplicationGroupsResultTypeDef",
+    {"Marker": str, "GlobalReplicationGroups": List[GlobalReplicationGroupTypeDef]},
+    total=False,
+)
+
 DescribeSnapshotsListMessageTypeDef = TypedDict(
     "DescribeSnapshotsListMessageTypeDef",
     {"Marker": str, "Snapshots": List[SnapshotTypeDef]},
     total=False,
 )
 
+DisassociateGlobalReplicationGroupResultTypeDef = TypedDict(
+    "DisassociateGlobalReplicationGroupResultTypeDef",
+    {"GlobalReplicationGroup": GlobalReplicationGroupTypeDef},
+    total=False,
+)
+
 EventTypeDef = TypedDict(
     "EventTypeDef",
     {
@@ -586,6 +677,18 @@ EventsMessageTypeDef = TypedDict(
     "EventsMessageTypeDef", {"Marker": str, "Events": List[EventTypeDef]}, total=False
 )
 
+FailoverGlobalReplicationGroupResultTypeDef = TypedDict(
+    "FailoverGlobalReplicationGroupResultTypeDef",
+    {"GlobalReplicationGroup": GlobalReplicationGroupTypeDef},
+    total=False,
+)
+
+IncreaseNodeGroupsInGlobalReplicationGroupResultTypeDef = TypedDict(
+    "IncreaseNodeGroupsInGlobalReplicationGroupResultTypeDef",
+    {"GlobalReplicationGroup": GlobalReplicationGroupTypeDef},
+    total=False,
+)
+
 IncreaseReplicaCountResultTypeDef = TypedDict(
     "IncreaseReplicaCountResultTypeDef", {"ReplicationGroup": ReplicationGroupTypeDef}, total=False
 )
@@ -600,6 +703,12 @@ ModifyCacheSubnetGroupResultTypeDef = TypedDict(
     total=False,
 )
 
+ModifyGlobalReplicationGroupResultTypeDef = TypedDict(
+    "ModifyGlobalReplicationGroupResultTypeDef",
+    {"GlobalReplicationGroup": GlobalReplicationGroupTypeDef},
+    total=False,
+)
+
 ModifyReplicationGroupResultTypeDef = TypedDict(
     "ModifyReplicationGroupResultTypeDef",
     {"ReplicationGroup": ReplicationGroupTypeDef},
@@ -652,10 +761,31 @@ PurchaseReservedCacheNodesOfferingResultTypeDef = TypedDict(
     total=False,
 )
 
+RebalanceSlotsInGlobalReplicationGroupResultTypeDef = TypedDict(
+    "RebalanceSlotsInGlobalReplicationGroupResultTypeDef",
+    {"GlobalReplicationGroup": GlobalReplicationGroupTypeDef},
+    total=False,
+)
+
 RebootCacheClusterResultTypeDef = TypedDict(
     "RebootCacheClusterResultTypeDef", {"CacheCluster": CacheClusterTypeDef}, total=False
 )
 
+ReshardingConfigurationTypeDef = TypedDict(
+    "ReshardingConfigurationTypeDef",
+    {"NodeGroupId": str, "PreferredAvailabilityZones": List[str]},
+    total=False,
+)
+
+RegionalConfigurationTypeDef = TypedDict(
+    "RegionalConfigurationTypeDef",
+    {
+        "ReplicationGroupId": str,
+        "ReplicationGroupRegion": str,
+        "ReshardingConfiguration": List[ReshardingConfigurationTypeDef],
+    },
+)
+
 ReplicationGroupMessageTypeDef = TypedDict(
     "ReplicationGroupMessageTypeDef",
     {"Marker": str, "ReplicationGroups": List[ReplicationGroupTypeDef]},
@@ -689,12 +819,6 @@ ReservedCacheNodesOfferingMessageTypeDef = TypedDict(
     total=False,
 )
 
-ReshardingConfigurationTypeDef = TypedDict(
-    "ReshardingConfigurationTypeDef",
-    {"NodeGroupId": str, "PreferredAvailabilityZones": List[str]},
-    total=False,
-)
-
 RevokeCacheSecurityGroupIngressResultTypeDef = TypedDict(
     "RevokeCacheSecurityGroupIngressResultTypeDef",
     {"CacheSecurityGroup": CacheSecurityGroupTypeDef},
